@@ -23,10 +23,6 @@
 
 #include <QApplication>
 
-#if QT_VERSION < 0x050000
-Q_EXPORT_PLUGIN2( breeze-qt, Breeze::StylePlugin )
-#endif
-
 namespace Breeze
 {
 
